@@ -159,7 +159,7 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget *parent)
     itemFilter->addMimeTypeExclusionFilter(Collection::mimeType());
     itemFilter->setHeaderGroup(EntityTreeModel::ItemListHeaders);
 
-    const KConfigGroup group = KSharedConfig::openConfig()->group("FavoriteCollectionsModel");
+    const KConfigGroup group = KSharedConfig::openConfig()->group(QStringLiteral("FavoriteCollectionsModel"));
     connect(mBrowserModel, &AkonadiBrowserModel::columnsChanged, itemFilter, &EntityMimeTypeFilterModel::invalidate);
     auto sortModel = new AkonadiBrowserSortModel(mBrowserModel, this);
     sortModel->setDynamicSortFilter(true);
@@ -198,12 +198,12 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget *parent)
 #if ENABLE_CONTENTVIEWS
     auto w = new QWidget;
     w->setLayout(new QVBoxLayout);
-    w->layout()->addWidget(mContactView = new ContactEditor::ContactViewer);
+    w->layout()->addWidget(mContactView = new Akonadi::ContactViewer);
     contentUi.stack->addWidget(w);
 
     w = new QWidget;
     w->setLayout(new QVBoxLayout);
-    w->layout()->addWidget(mContactGroupView = new ContactEditor::ContactGroupViewer);
+    w->layout()->addWidget(mContactGroupView = new Akonadi::ContactGroupViewer);
     contentUi.stack->addWidget(w);
 
     w = new QWidget;
@@ -242,7 +242,7 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget *parent)
     xmlGuiWindow->actionCollection()->addAction(QStringLiteral("akonadiconsole_cacheonly"), mCacheOnlyAction);
     connect(mCacheOnlyAction, &KToggleAction::toggled, this, &BrowserWidget::updateItemFetchScope);
 
-    m_stateMaintainer = new KViewStateMaintainer<ETMViewStateSaver>(KSharedConfig::openConfig()->group("CollectionViewState"), this);
+    m_stateMaintainer = new KViewStateMaintainer<ETMViewStateSaver>(KSharedConfig::openConfig()->group(QStringLiteral("CollectionViewState")), this);
     m_stateMaintainer->setView(mCollectionView);
 
     m_stateMaintainer->restoreState();
@@ -549,18 +549,6 @@ void BrowserWidget::tagViewContextMenuRequested(const QPoint &pos)
     menu->addAction(QIcon::fromTheme(QStringLiteral("list-add")), i18n("&Add tag..."), this, &BrowserWidget::addTagRequested);
     if (index.isValid()) {
         menu->addAction(i18n("Add &subtag..."), this, &BrowserWidget::addSubTagRequested);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        menu->addAction(QIcon::fromTheme(QStringLiteral("document-edit")),
-                        i18n("&Edit tag..."),
-                        this,
-                        &BrowserWidget::editTagRequested,
-                        QKeySequence(Qt::Key_Return));
-        menu->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")),
-                        i18n("&Delete tag..."),
-                        this,
-                        &BrowserWidget::removeTagRequested,
-                        QKeySequence::Delete);
-#else
         menu->addAction(QIcon::fromTheme(QStringLiteral("document-edit")),
                         i18n("&Edit tag..."),
                         QKeySequence(Qt::Key_Return),
@@ -572,7 +560,6 @@ void BrowserWidget::tagViewContextMenuRequested(const QPoint &pos)
                         this,
                         &BrowserWidget::removeTagRequested);
 
-#endif
         menu->setProperty("Tag", index.data(TagModel::TagRole));
     }
 
@@ -582,7 +569,7 @@ void BrowserWidget::tagViewContextMenuRequested(const QPoint &pos)
 void BrowserWidget::addTagRequested()
 {
     auto dlg = new TagPropertiesDialog(this);
-    dlg->setWindowTitle(i18n("Add Tag"));
+    dlg->setWindowTitle(i18nc("@title:window", "Add Tag"));
     connect(dlg, &TagPropertiesDialog::accepted, this, &BrowserWidget::createTag);
     connect(dlg, &TagPropertiesDialog::rejected, dlg, &TagPropertiesDialog::deleteLater);
     dlg->show();
@@ -597,7 +584,7 @@ void BrowserWidget::addSubTagRequested()
     tag.setParent(parentTag);
 
     auto dlg = new TagPropertiesDialog(tag, this);
-    dlg->setWindowTitle(i18n("Add Subtag"));
+    dlg->setWindowTitle(i18nc("@title:window", "Add Subtag"));
     connect(dlg, &TagPropertiesDialog::accepted, this, &BrowserWidget::createTag);
     connect(dlg, &TagPropertiesDialog::rejected, dlg, &TagPropertiesDialog::deleteLater);
     dlg->show();
@@ -608,7 +595,7 @@ void BrowserWidget::editTagRequested()
     auto action = qobject_cast<QAction *>(sender());
     const auto tag = action->parent()->property("Tag").value<Akonadi::Tag>();
     auto dlg = new TagPropertiesDialog(tag, this);
-    dlg->setWindowTitle(i18n("Modify Tag"));
+    dlg->setWindowTitle(i18nc("@title:window", "Modify Tag"));
     connect(dlg, &TagPropertiesDialog::accepted, this, &BrowserWidget::modifyTag);
     connect(dlg, &TagPropertiesDialog::rejected, dlg, &TagPropertiesDialog::deleteLater);
     dlg->show();
@@ -625,7 +612,7 @@ void BrowserWidget::tagViewDoubleClicked(const QModelIndex &index)
     Q_ASSERT(tag.isValid());
 
     auto dlg = new TagPropertiesDialog(tag, this);
-    dlg->setWindowTitle(i18n("Modify Tag"));
+    dlg->setWindowTitle(i18nc("@title:window", "Modify Tag"));
     connect(dlg, &TagPropertiesDialog::accepted, this, &BrowserWidget::modifyTag);
     connect(dlg, &TagPropertiesDialog::rejected, dlg, &TagPropertiesDialog::deleteLater);
     dlg->show();
@@ -668,3 +655,5 @@ void BrowserWidget::modifyTag()
         new TagModifyJob(dlg->tag(), this);
     }
 }
+
+#include "moc_browserwidget.cpp"
