@@ -95,13 +95,13 @@ Logging::Logging(QWidget *parent)
     new LoggerAdaptor(this);
     QDBusConnection::sessionBus().registerObject(DBUS_PATH, this, QDBusConnection::ExportAdaptors);
 
-    KConfigGroup config(KSharedConfig::openConfig(), "Logging");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("Logging"));
     mView->header()->restoreState(config.readEntry<QByteArray>("view", QByteArray()));
 }
 
 Logging::~Logging()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "Logging");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("Logging"));
     config.writeEntry("view", mView->header()->saveState());
 }
 
@@ -150,3 +150,5 @@ void Logging::saveToFile()
         stream << msg.message << "\n";
     }
 }
+
+#include "moc_logging.cpp"
