@@ -109,15 +109,24 @@ SearchWidget::SearchWidget(QWidget *parent)
 
     openStore(0);
 
-    KConfigGroup config(KSharedConfig::openConfig(), "SearchWidget");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("SearchWidget"));
     mQueryWidget->setPlainText(config.readEntry("query"));
 }
 
 SearchWidget::~SearchWidget()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "SearchWidget");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("SearchWidget"));
     config.writeEntry("query", mQueryWidget->toPlainText());
     config.sync();
+    closeDataBase();
+}
+
+void SearchWidget::closeDataBase()
+{
+    if (mDatabase) {
+        mDatabase->close();
+        delete mDatabase;
+    }
 }
 
 void SearchWidget::openStore(int idx)
@@ -126,10 +135,7 @@ void SearchWidget::openStore(int idx)
     auto xapianStore = store.objectCast<Akonadi::Search::XapianSearchStore>();
     Q_ASSERT(xapianStore);
 
-    if (mDatabase) {
-        mDatabase->close();
-        delete mDatabase;
-    }
+    closeDataBase();
 
     try {
         qCDebug(AKONADICONSOLE_LOG) << "Opening store" << xapianStore->dbPath();
@@ -226,3 +232,5 @@ void SearchWidget::itemFetched(KJob *job)
         mItemView->setPlainText(QString::fromUtf8(item.payloadData()));
     }
 }
+
+#include "moc_searchwidget.cpp"
